@@ -11,17 +11,18 @@ import (
 	"testing"
 	"time"
 
-	"github.com/fortytw2/leaktest"
+	"github.com/pkg/errors"
 	"github.com/prometheus/prometheus/pkg/labels"
 	"github.com/prometheus/prometheus/pkg/timestamp"
-	"github.com/prometheus/prometheus/tsdb"
+	"github.com/prometheus/prometheus/storage"
 	"github.com/prometheus/prometheus/tsdb/chunkenc"
-	"github.com/thanos-io/thanos/pkg/testutil/e2eutil"
 
 	"github.com/thanos-io/thanos/pkg/component"
+	"github.com/thanos-io/thanos/pkg/promclient"
 	"github.com/thanos-io/thanos/pkg/store/storepb"
 	"github.com/thanos-io/thanos/pkg/store/storepb/prompb"
 	"github.com/thanos-io/thanos/pkg/testutil"
+	"github.com/thanos-io/thanos/pkg/testutil/e2eutil"
 )
 
 func TestPrometheusStore_Series_e2e(t *testing.T) {
@@ -36,7 +37,7 @@ func TestPrometheusStore_Series_promOnPath_e2e(t *testing.T) {
 func testPrometheusStoreSeriesE2e(t *testing.T, prefix string) {
 	t.Helper()
 
-	defer leaktest.CheckTimeout(t, 10*time.Second)()
+	defer testutil.TolerantVerifyLeak(t)
 
 	p, err := e2eutil.NewPrometheusOnPath(prefix)
 	testutil.Ok(t, err)
@@ -62,7 +63,7 @@ func testPrometheusStoreSeriesE2e(t *testing.T, prefix string) {
 	testutil.Ok(t, err)
 
 	limitMinT := int64(0)
-	proxy, err := NewPrometheusStore(nil, nil, u, component.Sidecar,
+	proxy, err := NewPrometheusStore(nil, promclient.NewDefaultClient(), u, component.Sidecar,
 		func() labels.Labels { return labels.FromStrings("region", "eu-west") },
 		func() (int64, int64) { return limitMinT, -1 }) // Maxt does not matter.
 	testutil.Ok(t, err)
@@ -85,7 +86,7 @@ func testPrometheusStoreSeriesE2e(t *testing.T, prefix string) {
 			{Name: "a", Value: "b"},
 			{Name: "region", Value: "eu-west"},
 		}, srv.SeriesSet[0].Labels)
-
+		testutil.Equals(t, []string(nil), srv.Warnings)
 		testutil.Equals(t, 1, len(srv.SeriesSet[0].Chunks))
 
 		c := srv.SeriesSet[0].Chunks[0]
@@ -122,6 +123,7 @@ func testPrometheusStoreSeriesE2e(t *testing.T, prefix string) {
 		testutil.Equals(t, 1, len(srv.SeriesSet[0].Chunks))
 
 		c := srv.SeriesSet[0].Chunks[0]
+		testutil.Equals(t, []string(nil), srv.Warnings)
 		testutil.Equals(t, storepb.Chunk_XOR, c.Raw.Type)
 
 		chk, err := chunkenc.FromData(chunkenc.EncXOR, c.Raw.Data)
@@ -142,28 +144,9 @@ func testPrometheusStoreSeriesE2e(t *testing.T, prefix string) {
 			},
 		}, srv)
 		testutil.NotOk(t, err)
+		testutil.Equals(t, []string(nil), srv.Warnings)
 		testutil.Equals(t, "rpc error: code = InvalidArgument desc = no matchers specified (excluding external labels)", err.Error())
 	}
-	// Set no-chunk option to only get the series labels.
-	{
-		srv := newStoreSeriesServer(ctx)
-		testutil.Ok(t, proxy.Series(&storepb.SeriesRequest{
-			MinTime: 0,
-			MaxTime: baseT + 300,
-			Matchers: []storepb.LabelMatcher{
-				{Type: storepb.LabelMatcher_EQ, Name: "a", Value: "b"},
-			},
-			SkipChunks: true,
-		}, srv))
-		testutil.Equals(t, 1, len(srv.SeriesSet))
-
-		testutil.Equals(t, []storepb.Label{
-			{Name: "a", Value: "b"},
-			{Name: "region", Value: "eu-west"},
-		}, srv.SeriesSet[0].Labels)
-
-		testutil.Equals(t, 0, len(srv.SeriesSet[0].Chunks))
-	}
 }
 
 type sample struct {
@@ -188,7 +171,7 @@ func getExternalLabels() labels.Labels {
 func TestPrometheusStore_SeriesLabels_e2e(t *testing.T) {
 	t.Helper()
 
-	defer leaktest.CheckTimeout(t, 10*time.Second)()
+	defer testutil.TolerantVerifyLeak(t)
 
 	p, err := e2eutil.NewPrometheus()
 	testutil.Ok(t, err)
@@ -197,13 +180,13 @@ func TestPrometheusStore_SeriesLabels_e2e(t *testing.T) {
 	baseT := timestamp.FromTime(time.Now()) / 1000 * 1000
 
 	a := p.Appender()
-	_, err = a.Add(labels.FromStrings("a", "b"), baseT+100, 1)
+	_, err = a.Add(labels.FromStrings("a", "b", "b", "d"), baseT+100, 1)
 	testutil.Ok(t, err)
-	_, err = a.Add(labels.FromStrings("a", "c", "job", "test"), baseT+200, 2)
+	_, err = a.Add(labels.FromStrings("a", "c", "b", "d", "job", "test"), baseT+200, 2)
 	testutil.Ok(t, err)
-	_, err = a.Add(labels.FromStrings("a", "d", "job", "test"), baseT+300, 3)
+	_, err = a.Add(labels.FromStrings("a", "d", "b", "d", "job", "test"), baseT+300, 3)
 	testutil.Ok(t, err)
-	_, err = a.Add(labels.FromStrings("job", "test"), baseT+400, 4)
+	_, err = a.Add(labels.FromStrings("b", "d", "job", "test"), baseT+400, 4)
 	testutil.Ok(t, err)
 	testutil.Ok(t, a.Commit())
 
@@ -215,82 +198,162 @@ func TestPrometheusStore_SeriesLabels_e2e(t *testing.T) {
 	u, err := url.Parse(fmt.Sprintf("http://%s", p.Addr()))
 	testutil.Ok(t, err)
 
-	promStore, err := NewPrometheusStore(nil, nil, u, component.Sidecar,
+	promStore, err := NewPrometheusStore(nil, promclient.NewDefaultClient(), u, component.Sidecar,
 		func() labels.Labels { return labels.FromStrings("region", "eu-west") },
 		func() (int64, int64) { return math.MinInt64/1000 + 62135596801, math.MaxInt64/1000 - 62135596801 })
 	testutil.Ok(t, err)
 
-	{
-		res, err := promStore.seriesLabels(ctx, []storepb.LabelMatcher{
-			{Type: storepb.LabelMatcher_EQ, Name: "a", Value: "b"},
-		}, baseT, baseT+300)
-		testutil.Ok(t, err)
-
-		testutil.Equals(t, len(res), 1)
-		testutil.Equals(t, labels.FromMap(res[0]), labels.Labels{{Name: "a", Value: "b"}})
-	}
-	{
-		res, err := promStore.seriesLabels(ctx, []storepb.LabelMatcher{
-			{Type: storepb.LabelMatcher_EQ, Name: "job", Value: "foo"},
-		}, baseT, baseT+300)
-		testutil.Ok(t, err)
-
-		testutil.Equals(t, len(res), 0)
-	}
-	{
-		res, err := promStore.seriesLabels(ctx, []storepb.LabelMatcher{
-			{Type: storepb.LabelMatcher_NEQ, Name: "a", Value: "b"},
-			{Type: storepb.LabelMatcher_EQ, Name: "job", Value: "test"},
-		}, baseT, baseT+300)
-		testutil.Ok(t, err)
-
-		// Get two metrics {a="c", job="test"} and {a="d", job="test"}.
-		testutil.Equals(t, len(res), 2)
-		for _, r := range res {
-			testutil.Equals(t, labels.FromMap(r).Has("a"), true)
-			testutil.Equals(t, labels.FromMap(r).Get("job"), "test")
-		}
-	}
-	{
-		res, err := promStore.seriesLabels(ctx, []storepb.LabelMatcher{
-			{Type: storepb.LabelMatcher_EQ, Name: "job", Value: "test"},
-		}, baseT, baseT+300)
-		testutil.Ok(t, err)
-
-		// Get two metrics.
-		testutil.Equals(t, len(res), 2)
-		for _, r := range res {
-			testutil.Equals(t, labels.FromMap(r).Has("a"), true)
-			testutil.Equals(t, labels.FromMap(r).Get("job"), "test")
-		}
-	}
-	{
-		res, err := promStore.seriesLabels(ctx, []storepb.LabelMatcher{
-			{Type: storepb.LabelMatcher_EQ, Name: "job", Value: "test"},
-		}, baseT+400, baseT+400)
-		testutil.Ok(t, err)
-
-		// In baseT + 400 we can just get one series.
-		testutil.Equals(t, len(res), 1)
-		testutil.Equals(t, len(res[0]), 1)
-		testutil.Equals(t, labels.FromMap(res[0]).Get("job"), "test")
-	}
-	// This test case is to test when start time and end time is not specified.
-	{
-		minTime, maxTime := promStore.timestamps()
-		res, err := promStore.seriesLabels(ctx, []storepb.LabelMatcher{
-			{Type: storepb.LabelMatcher_EQ, Name: "job", Value: "test"},
-		}, minTime, maxTime)
-		testutil.Ok(t, err)
-		testutil.Equals(t, len(res), 3)
-		for _, r := range res {
-			testutil.Equals(t, labels.FromMap(r).Get("job"), "test")
-		}
+	for _, tcase := range []struct {
+		req         *storepb.SeriesRequest
+		expected    []storepb.Series
+		expectedErr error
+	}{
+		{
+			req: &storepb.SeriesRequest{
+				SkipChunks: true,
+				Matchers:   []storepb.LabelMatcher{},
+				MinTime:    baseT - 10000000000,
+				MaxTime:    baseT + 10000000000,
+			},
+			expectedErr: errors.New("rpc error: code = InvalidArgument desc = no matchers specified (excluding external labels)"),
+		},
+		{
+			req: &storepb.SeriesRequest{
+				SkipChunks: true,
+				Matchers: []storepb.LabelMatcher{
+					{Type: storepb.LabelMatcher_RE, Name: "wrong-chars-in-label-name(hyphen)", Value: "adsf"},
+				},
+				MinTime: baseT - 10000000000,
+				MaxTime: baseT + 10000000000,
+			},
+			expectedErr: errors.New("rpc error: code = InvalidArgument desc = expected 2xx response, got 400. Body: {\"status\":\"error\",\"errorType\":\"bad_data\",\"error\":\"1:7: parse error: unexpected character inside braces: '-'\"}"),
+		},
+		{
+			req: &storepb.SeriesRequest{
+				SkipChunks: true,
+				Matchers: []storepb.LabelMatcher{
+					{Type: storepb.LabelMatcher_EQ, Name: "non_existing", Value: "something"},
+				},
+				MinTime: baseT - 10000000000,
+				MaxTime: baseT + 10000000000,
+			},
+		},
+		{
+			req: &storepb.SeriesRequest{
+				SkipChunks: true,
+				Matchers: []storepb.LabelMatcher{
+					{Type: storepb.LabelMatcher_EQ, Name: "a", Value: "b"},
+				},
+				MinTime: baseT,
+				MaxTime: baseT + 300,
+			},
+			expected: []storepb.Series{
+				{
+					Labels: []storepb.Label{{Name: "a", Value: "b"}, {Name: "b", Value: "d"}, {Name: "region", Value: "eu-west"}},
+				},
+			},
+		},
+		{
+			req: &storepb.SeriesRequest{
+				SkipChunks: true,
+				Matchers: []storepb.LabelMatcher{
+					{Type: storepb.LabelMatcher_EQ, Name: "job", Value: "foo"},
+				},
+				MinTime: baseT,
+				MaxTime: baseT + 300,
+			},
+		},
+		{
+			req: &storepb.SeriesRequest{
+				SkipChunks: true,
+				Matchers: []storepb.LabelMatcher{
+					{Type: storepb.LabelMatcher_NEQ, Name: "a", Value: "b"},
+					{Type: storepb.LabelMatcher_EQ, Name: "job", Value: "test"},
+				},
+				MinTime: baseT,
+				MaxTime: baseT + 300,
+			},
+			expected: []storepb.Series{
+				{
+					Labels: []storepb.Label{{Name: "a", Value: "c"}, {Name: "b", Value: "d"}, {Name: "job", Value: "test"}, {Name: "region", Value: "eu-west"}},
+				},
+				{
+					Labels: []storepb.Label{{Name: "a", Value: "d"}, {Name: "b", Value: "d"}, {Name: "job", Value: "test"}, {Name: "region", Value: "eu-west"}},
+				},
+			},
+		},
+		{
+			req: &storepb.SeriesRequest{
+				SkipChunks: true,
+				Matchers: []storepb.LabelMatcher{
+					{Type: storepb.LabelMatcher_EQ, Name: "job", Value: "test"},
+				},
+				MinTime: baseT,
+				MaxTime: baseT + 300,
+			},
+			expected: []storepb.Series{
+				{
+					Labels: []storepb.Label{{Name: "a", Value: "c"}, {Name: "b", Value: "d"}, {Name: "job", Value: "test"}, {Name: "region", Value: "eu-west"}},
+				},
+				{
+					Labels: []storepb.Label{{Name: "a", Value: "d"}, {Name: "b", Value: "d"}, {Name: "job", Value: "test"}, {Name: "region", Value: "eu-west"}},
+				},
+			},
+		},
+		{
+			req: &storepb.SeriesRequest{
+				SkipChunks: true,
+				Matchers: []storepb.LabelMatcher{
+					{Type: storepb.LabelMatcher_EQ, Name: "job", Value: "test"},
+				},
+				MinTime: baseT + 400,
+				MaxTime: baseT + 400,
+			},
+			expected: []storepb.Series{
+				{
+					Labels: []storepb.Label{{Name: "b", Value: "d"}, {Name: "job", Value: "test"}, {Name: "region", Value: "eu-west"}},
+				},
+			},
+		},
+		{
+			req: &storepb.SeriesRequest{
+				SkipChunks: true,
+				Matchers: []storepb.LabelMatcher{
+					{Type: storepb.LabelMatcher_EQ, Name: "job", Value: "test"},
+				},
+				MinTime: func() int64 { minTime, _ := promStore.timestamps(); return minTime }(),
+				MaxTime: func() int64 { _, maxTime := promStore.timestamps(); return maxTime }(),
+			},
+			expected: []storepb.Series{
+				{
+					Labels: []storepb.Label{{Name: "a", Value: "c"}, {Name: "b", Value: "d"}, {Name: "job", Value: "test"}, {Name: "region", Value: "eu-west"}},
+				},
+				{
+					Labels: []storepb.Label{{Name: "a", Value: "d"}, {Name: "b", Value: "d"}, {Name: "job", Value: "test"}, {Name: "region", Value: "eu-west"}},
+				},
+				{
+					Labels: []storepb.Label{{Name: "b", Value: "d"}, {Name: "job", Value: "test"}, {Name: "region", Value: "eu-west"}},
+				},
+			},
+		},
+	} {
+		t.Run("", func(t *testing.T) {
+			srv := newStoreSeriesServer(ctx)
+			err = promStore.Series(tcase.req, srv)
+			if tcase.expectedErr != nil {
+				testutil.NotOk(t, err)
+				testutil.Equals(t, tcase.expectedErr.Error(), err.Error())
+				return
+			}
+			testutil.Ok(t, err)
+			testutil.Equals(t, []string(nil), srv.Warnings)
+			testutil.Equals(t, tcase.expected, srv.SeriesSet)
+		})
 	}
 }
 
-func TestPrometheusStore_LabelValues_e2e(t *testing.T) {
-	defer leaktest.CheckTimeout(t, 10*time.Second)()
+func TestPrometheusStore_LabelNames_e2e(t *testing.T) {
+	defer testutil.TolerantVerifyLeak(t)
 
 	p, err := e2eutil.NewPrometheus()
 	testutil.Ok(t, err)
@@ -313,20 +376,77 @@ func TestPrometheusStore_LabelValues_e2e(t *testing.T) {
 	u, err := url.Parse(fmt.Sprintf("http://%s", p.Addr()))
 	testutil.Ok(t, err)
 
-	proxy, err := NewPrometheusStore(nil, nil, u, component.Sidecar, getExternalLabels, nil)
+	proxy, err := NewPrometheusStore(nil, promclient.NewDefaultClient(), u, component.Sidecar, getExternalLabels, nil)
+	testutil.Ok(t, err)
+
+	resp, err := proxy.LabelNames(ctx, &storepb.LabelNamesRequest{
+		Start: timestamp.FromTime(minTime),
+		End:   timestamp.FromTime(maxTime),
+	})
+	testutil.Ok(t, err)
+	testutil.Equals(t, []string(nil), resp.Warnings)
+	testutil.Equals(t, []string{"a"}, resp.Names)
+
+	// Outside time range.
+	resp, err = proxy.LabelNames(ctx, &storepb.LabelNamesRequest{
+		Start: timestamp.FromTime(maxTime.Add(-time.Second)),
+		End:   timestamp.FromTime(maxTime),
+	})
+	testutil.Ok(t, err)
+	testutil.Equals(t, []string(nil), resp.Warnings)
+	testutil.Equals(t, []string{}, resp.Names)
+}
+
+func TestPrometheusStore_LabelValues_e2e(t *testing.T) {
+	defer testutil.TolerantVerifyLeak(t)
+
+	p, err := e2eutil.NewPrometheus()
+	testutil.Ok(t, err)
+	defer func() { testutil.Ok(t, p.Stop()) }()
+
+	a := p.Appender()
+	_, err = a.Add(labels.FromStrings("a", "b"), 0, 1)
+	testutil.Ok(t, err)
+	_, err = a.Add(labels.FromStrings("a", "c"), 0, 1)
+	testutil.Ok(t, err)
+	_, err = a.Add(labels.FromStrings("a", "a"), 0, 1)
+	testutil.Ok(t, err)
+	testutil.Ok(t, a.Commit())
+
+	ctx, cancel := context.WithCancel(context.Background())
+	defer cancel()
+
+	testutil.Ok(t, p.Start())
+
+	u, err := url.Parse(fmt.Sprintf("http://%s", p.Addr()))
+	testutil.Ok(t, err)
+
+	proxy, err := NewPrometheusStore(nil, promclient.NewDefaultClient(), u, component.Sidecar, getExternalLabels, nil)
 	testutil.Ok(t, err)
 
 	resp, err := proxy.LabelValues(ctx, &storepb.LabelValuesRequest{
 		Label: "a",
+		Start: timestamp.FromTime(minTime),
+		End:   timestamp.FromTime(maxTime),
 	})
 	testutil.Ok(t, err)
-
+	testutil.Equals(t, []string(nil), resp.Warnings)
 	testutil.Equals(t, []string{"a", "b", "c"}, resp.Values)
+
+	// Outside time range.
+	resp, err = proxy.LabelValues(ctx, &storepb.LabelValuesRequest{
+		Label: "a",
+		Start: timestamp.FromTime(maxTime.Add(-time.Second)),
+		End:   timestamp.FromTime(maxTime),
+	})
+	testutil.Ok(t, err)
+	testutil.Equals(t, []string(nil), resp.Warnings)
+	testutil.Equals(t, []string{}, resp.Values)
 }
 
 // Test to check external label values retrieve.
 func TestPrometheusStore_ExternalLabelValues_e2e(t *testing.T) {
-	defer leaktest.CheckTimeout(t, 10*time.Second)()
+	defer testutil.TolerantVerifyLeak(t)
 
 	p, err := e2eutil.NewPrometheus()
 	testutil.Ok(t, err)
@@ -347,7 +467,7 @@ func TestPrometheusStore_ExternalLabelValues_e2e(t *testing.T) {
 	u, err := url.Parse(fmt.Sprintf("http://%s", p.Addr()))
 	testutil.Ok(t, err)
 
-	proxy, err := NewPrometheusStore(nil, nil, u, component.Sidecar, getExternalLabels, nil)
+	proxy, err := NewPrometheusStore(nil, promclient.NewDefaultClient(), u, component.Sidecar, getExternalLabels, nil)
 	testutil.Ok(t, err)
 
 	resp, err := proxy.LabelValues(ctx, &storepb.LabelValuesRequest{
@@ -366,7 +486,7 @@ func TestPrometheusStore_ExternalLabelValues_e2e(t *testing.T) {
 }
 
 func TestPrometheusStore_Series_MatchExternalLabel_e2e(t *testing.T) {
-	defer leaktest.CheckTimeout(t, 10*time.Second)()
+	defer testutil.TolerantVerifyLeak(t)
 
 	p, err := e2eutil.NewPrometheus()
 	testutil.Ok(t, err)
@@ -391,7 +511,7 @@ func TestPrometheusStore_Series_MatchExternalLabel_e2e(t *testing.T) {
 	u, err := url.Parse(fmt.Sprintf("http://%s", p.Addr()))
 	testutil.Ok(t, err)
 
-	proxy, err := NewPrometheusStore(nil, nil, u, component.Sidecar,
+	proxy, err := NewPrometheusStore(nil, promclient.NewDefaultClient(), u, component.Sidecar,
 		func() labels.Labels { return labels.FromStrings("region", "eu-west") },
 		func() (int64, int64) { return 0, math.MaxInt64 })
 	testutil.Ok(t, err)
@@ -431,12 +551,12 @@ func TestPrometheusStore_Series_MatchExternalLabel_e2e(t *testing.T) {
 }
 
 func TestPrometheusStore_Info(t *testing.T) {
-	defer leaktest.CheckTimeout(t, 10*time.Second)()
+	defer testutil.TolerantVerifyLeak(t)
 
 	ctx, cancel := context.WithCancel(context.Background())
 	defer cancel()
 
-	proxy, err := NewPrometheusStore(nil, nil, nil, component.Sidecar,
+	proxy, err := NewPrometheusStore(nil, promclient.NewDefaultClient(), nil, component.Sidecar,
 		func() labels.Labels { return labels.FromStrings("region", "eu-west") },
 		func() (int64, int64) { return 123, 456 })
 	testutil.Ok(t, err)
@@ -450,7 +570,7 @@ func TestPrometheusStore_Info(t *testing.T) {
 	testutil.Equals(t, int64(456), resp.MaxTime)
 }
 
-func testSeries_SplitSamplesIntoChunksWithMaxSizeOfUint16_e2e(t *testing.T, appender tsdb.Appender, newStore func() storepb.StoreServer) {
+func testSeries_SplitSamplesIntoChunksWithMaxSizeOf120(t *testing.T, appender storage.Appender, newStore func() storepb.StoreServer) {
 	baseT := timestamp.FromTime(time.Now().AddDate(0, 0, -2)) / 1000 * 1000
 
 	offset := int64(2*math.MaxUint16 + 5)
@@ -485,36 +605,36 @@ func testSeries_SplitSamplesIntoChunksWithMaxSizeOfUint16_e2e(t *testing.T, appe
 		{Name: "region", Value: "eu-west"},
 	}, firstSeries.Labels)
 
-	testutil.Equals(t, 3, len(firstSeries.Chunks))
+	testutil.Equals(t, 1093, len(firstSeries.Chunks))
 
 	chunk, err := chunkenc.FromData(chunkenc.EncXOR, firstSeries.Chunks[0].Raw.Data)
 	testutil.Ok(t, err)
-	testutil.Equals(t, math.MaxUint16, chunk.NumSamples())
+	testutil.Equals(t, 120, chunk.NumSamples())
 
 	chunk, err = chunkenc.FromData(chunkenc.EncXOR, firstSeries.Chunks[1].Raw.Data)
 	testutil.Ok(t, err)
-	testutil.Equals(t, math.MaxUint16, chunk.NumSamples())
+	testutil.Equals(t, 120, chunk.NumSamples())
 
-	chunk, err = chunkenc.FromData(chunkenc.EncXOR, firstSeries.Chunks[2].Raw.Data)
+	chunk, err = chunkenc.FromData(chunkenc.EncXOR, firstSeries.Chunks[len(firstSeries.Chunks)-1].Raw.Data)
 	testutil.Ok(t, err)
-	testutil.Equals(t, 5, chunk.NumSamples())
+	testutil.Equals(t, 35, chunk.NumSamples())
 }
 
 // Regression test for https://github.com/thanos-io/thanos/issues/396.
-func TestPrometheusStore_Series_SplitSamplesIntoChunksWithMaxSizeOfUint16_e2e(t *testing.T) {
-	defer leaktest.CheckTimeout(t, 10*time.Second)()
+func TestPrometheusStore_Series_SplitSamplesIntoChunksWithMaxSizeOf120(t *testing.T) {
+	defer testutil.TolerantVerifyLeak(t)
 
 	p, err := e2eutil.NewPrometheus()
 	testutil.Ok(t, err)
 	defer func() { testutil.Ok(t, p.Stop()) }()
 
-	testSeries_SplitSamplesIntoChunksWithMaxSizeOfUint16_e2e(t, p.Appender(), func() storepb.StoreServer {
+	testSeries_SplitSamplesIntoChunksWithMaxSizeOf120(t, p.Appender(), func() storepb.StoreServer {
 		testutil.Ok(t, p.Start())
 
 		u, err := url.Parse(fmt.Sprintf("http://%s", p.Addr()))
 		testutil.Ok(t, err)
 
-		proxy, err := NewPrometheusStore(nil, nil, u, component.Sidecar,
+		proxy, err := NewPrometheusStore(nil, promclient.NewDefaultClient(), u, component.Sidecar,
 			func() labels.Labels { return labels.FromStrings("region", "eu-west") },
 			func() (int64, int64) { return 0, math.MaxInt64 })
 		testutil.Ok(t, err)
